@@ -10,9 +10,17 @@
 #' @param bin \code{integer} vector with the bin number for each data point
 #' @param nbins \code{integer} maximum bin number 
 #' @param nlevels \code{integer} number of levels used in x
+#' @param ... used by binned_tabulate.ff
 #' @return \code{numeric} matrix where each row is a bin and each column a level
 #' @export
-binned_tabulate <- function (x, bin, nbins=max(bin), nlevels=nlevels(x)){
+binned_tabulate <- function (x, bin, nbins=max(bin), nlevels=nlevels(x), ...){
+  UseMethod("binned_tabulate")
+}
+
+#' @rdname binned_tabulate
+#' @method binned_tabulate default
+#' @S3method binned_tabulate default
+binned_tabulate.default <- function (x, bin, nbins=max(bin), nlevels=nlevels(x), ...){
    stopifnot(length(x)==length(bin))
    
    res <- .Call("binned_tabulate", x, as.integer(bin), as.integer(nbins), as.integer(nlevels), PACKAGE = "ffbase")
@@ -23,14 +31,15 @@ binned_tabulate <- function (x, bin, nbins=max(bin), nlevels=nlevels(x)){
 }
 
 #' @rdname binned_tabulate
-#' @usage \method{binned_tabulate}{ff} (x, bin, nbins=max(bin), nlevels=nlevels(x), ...)
-#' @param ... passed on to chunk
-#' @export
+#' @method binned_tabulate ff
+#' @S3method binned_tabulate ff
+#' @export binned_tabulate.ff
 binned_tabulate.ff <- function(x, bin, nbins=max(bin), nlevels=nlevels(x), ...){
   lev <- if (nlevels(x)) c("na", levels(x))
          else c("na", 1:nlevels)
   res <- matrix(0, nrow=nbins, ncol=length(lev), dimnames=list(bin=1:nbins, level=lev))
   for (i in chunk(x, ...)){
+    Log$chunk(i)
     res <- res + .Call("binned_tabulate", x[i], as.integer(bin[i]), as.integer(nbins), as.integer(nlevels), PACKAGE = "ffbase")
   }
   res
