@@ -25,7 +25,7 @@ subset.ffdf <- function(x, subset, select, drop = FALSE, ...){
   } else {  
     ss <- as.expression(substitute(subset))
     try(ss <- subset, silent=TRUE)
-    idx <- ffwhich(x, ss)
+    idx <- ffwhich.ffdf(x, ss, envir=parent.frame())
   }
   if (missing(select)){
     select <- names(x)
