@@ -22,23 +22,25 @@ table.ff <- function( ...
   ###
   args <- list(...)
   tab <- NULL
+  useNA <- match.arg(useNA)
   
   dat <- do.call(ffdf, args) # create a ffdf  for estimating good chunking size and checking if ... have equal length
-  
+  colnames(dat) <- names(args)
   ### Cover non-factors like integers by adding a levels attribute
-  if(sum(!vmode(dat) %in% c("integer")) > 0){  	
+  if(sum(!vmode(dat) %in% c("byte", "short", "integer")) > 0){  	
     stop(sprintf("Only vmodes integer currently allowed - are you sure ... contains only factors or integers?"))
   }
-  nonfactors <- sapply(colnames(dat), FUN=function(column, dat) !is.factor(dat[[column]]), dat=dat)
+  nonfactors <- sapply(colnames(dat), FUN=function(column, dat) !is.factor.ff(dat[[column]]), dat=dat)
   nonfactors <- names(nonfactors)[nonfactors == TRUE]
-  for(column in nonfactors){
-    levels(dat[[column]]) <- unique(dat[[column]])[]
+  if(length(nonfactors) > 0){
+    for(column in nonfactors){
+      dat[[column]] <- as.character.ff(dat[[column]])
+    } 
   }
   
   for (i in chunk(dat)){
-    factors <- lapply(args, function(f){
-      f[i]
-    })
+    Log$chunk(i)
+    factors <- as.list(dat[i,, drop=FALSE])
     factors$exclude <- exclude
     factors$useNA <- useNA
     factors$deparse.level <- deparse.level
@@ -83,4 +85,4 @@ list.names <- function(...) {
 # setMethod( "table"
 # , "ff_vector"
 # , table.ff
-# )
\ No newline at end of file
+# )
